==> speech-analytic-testing_3.6.0_database.tar.gz: database/mssql/procedures/GetProcessInteractionsTask.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetProcessInteractionsTask]
(
	@VCC		VARCHAR(50),
	@ProcessId	VARCHAR(50)
)
AS
BEGIN
	SET NOCOUNT ON

	BEGIN
		-- ACTUALIZAMOS LOS REGISTROS DE INTERACCIONES SINCRONAS(CALL) Y RETORNAMOS LOS DETALLES DE LAS QUE SE VAN A TRANSCRIBIR

		-- Actualiza en el primer momento que se consulta a estos registros, con el valor 1 en el campo IsProcess. Indica que se encuentra utilizado por un proceso.
		UPDATE [dbo].[Audio] SET
			[dbo].[Audio].[IsProcess] = 1,	-- Indicar que se esta tomando como procesando para que ningun otro procesamiento en parelelo pueda utilizar el registro.
			[dbo].[Audio].[IsCancel] = null, -- Limpiamos el campo isCancel para retomar los audios que fallaron en procesos pasados
			[dbo].[Audio].[ErrorMessage] = NULL
		
		-- Retornamos todas las columnas a listar.
		OUTPUT INSERTED.[VCC]							'vcc',
				PA.[ProcessId]							'processId',
				'CALL'									'interactionType',
				INSERTED.[ID]							'id',
				INSERTED.[Section]						'section',
				INSERTED.[Part]							'part',
				INSERTED.[StartDate]					'startDate',
				INSERTED.[EndDate]						'endDate',
				INSERTED.[Campaign]						'campaign',
				INSERTED.[DispositionCode]				'dispositionCode',
				INSERTED.[Agent]						'agent',
				INSERTED.[Type]							'origin',
				INSERTED.[RelativePath]					'relativePath',
				INSERTED.[FileName]						'fileName',
				INSERTED.[Format]                       'format',
				INSERTED.[MediaInfoTime]                'mediaInfoTime',
				INSERTED.[NeedI6Update]					'needI6Update',
				0										'isDiariced',
				P.[Language]							'language',
				P.[DictionaryId]						'dictionaryId',
				P.Retranscription						'retranscription',
				P.Diarization							'diarization',
				P.ChannelChange							'channelchange',
				E.[Name]								'name',
				E.[Type]								'environmentType',
				E.[Description]							'description',
				E.[FTPDirectory]						'ftpDirectory',
				E.[ApiHost]								'apiHost',
				E.[ApiPort]								'apiPort',
				E.[ApiUser]								'apiUser',
				E.[ApiPassword]							'apiPassword',
				E.[DbDisabled]							'dbDisabled',
				E.[DbServer]							'dbServer',
				E.[DbPort]								'dbPort',
				E.[DbUser]								'dbUser',
				E.[DbPassword]							'dbPassword',
				E.[PbxDisabled]							'pbxDisabled',
				E.[PbxServer]							'pbxServer',
				E.[PbxPort]								'pbxPort',
				E.[PbxUser]								'pbxUser',
				E.[PbxPassword]							'pbxPassword',
				INSERTED.[DurationTime]					'durationTime'
		FROM [dbo].[ProcessAudio] PA (NOLOCK)
		INNER JOIN [dbo].[Audio] A (NOLOCK) 
			ON A.[VCC] = PA.[VCC]
				AND CONCAT(A.[ID], '_', A.[Section], '_', A.[Part]) = CONCAT(PA.[AudioId], '_', PA.[Section], '_', PA.[Part])
		INNER JOIN [dbo].[Process] P (NOLOCK) 
			ON P.[VCC] = A.[VCC]
				AND PA.ProcessId = P.[Name]
		INNER JOIN [dbo].[Environment] E (NOLOCK) 
			ON E.[VCC] = PA.[VCC]
				AND P.[Environment] = E.[Name]
		WHERE A.[VCC] = @VCC
			AND PA.[ProcessId] = @ProcessId
			AND (
				(
					ISNULL(A.[IsProcess], 0) = 0				
					AND 
					ISNULL(A.[IsTranscribed], 0) = 0	-- RETORNAR SOLO LAS INTERACCIONES QUE NO HAYAN SIDO TOMADAS POR OTRO PROCESS
				)
				OR 
				(
					A.[IsProcess] = 1						
					AND 
					A.[IsCancel] = 1
				)
			
				
				
			)					-- RETORNAR SOLO LAS INTERACCIONES QUE HAYAN SIDO TOMADAS Y CANCELADAS POR OTRO PROCESS

		-- ACTUALIZAMOS LOS REGISTROS DE INTERACCIONES ASINCRONAS Y RETORNAMOS LOS DETALLES DE LAS QUE SE VAN A TRANSCRIBIR
		UPDATE [dbo].[AsyncInteraction] 
		SET [dbo].[AsyncInteraction].[IsProcess] = 1,
			[dbo].[AsyncInteraction].[IsCancel] = NULL,
			[dbo].[AsyncInteraction].[ErrorMessage] = NULL
		OUTPUT INSERTED.[VCC]														'vcc',
				P.[Name]															'processId',
				INSERTED.[Channel]													'interactionType',
				INSERTED.[ID]														'id',
				INSERTED.[EndDate]													'endDate',
				INSERTED.[Folder]													'folder',
				INSERTED.[Campaign]													'campaign',
				INSERTED.[DispositionCode]											'dispositionCode',
				ISNULL(INSERTED.[LastTakedAgent], INSERTED.[FirstTakedAgent])		'agent',
				INSERTED.[Initiative]												'origin',
				INSERTED.[TotalMessages]											'totalMessages',
				INSERTED.[RawChar]													'rawChar',
				INSERTED.[ExportedContent]											'exportedContent',
				P.[Language]														'language',
				INSERTED.[FileName]                                                 'fileName',
				'allegro'															'environmentType',
				P.Retranscription													'retranscription'
		FROM [dbo].[ProcessAsyncInteraction] PAI (NOLOCK)
		INNER JOIN [dbo].[AsyncInteraction] AI (NOLOCK)
			ON AI.[ID] = PAI.[InteractionId]
				AND AI.[EndDate] = PAI.[EndDate]
		INNER JOIN [dbo].[Process] P (NOLOCK) 
			ON P.[Name] = PAI.[ProcessId] 
		WHERE AI.[VCC] = @VCC
			AND PAI.[ProcessId] = @ProcessId
			AND (
				(
					ISNULL(AI.[IsProcess], 0) = 0
					AND 
					ISNULL(AI.[IsTranscribed], 0) = 0)	-- RETORNAR SOLO LAS INTERACCIONES QUE NO HAYAN SIDO TOMADAS POR OTRO PROCESS
				OR 
				(
					AI.[IsProcess] = 1
					AND 
					AI.[IsCancel] = 1
				)

				
			)					-- RETORNAR SOLO LAS INTERACCIONES QUE HAYAN SIDO TOMADAS Y CANCELADAS POR OTRO PROCESS
	END

	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_3.7.0_database.tar.gz: database/mssql/procedures/GetProcessInteractionsTask.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetProcessInteractionsTask]
(
	@VCC		VARCHAR(50),
	@ProcessId	VARCHAR(50)
)
AS
BEGIN
	SET NOCOUNT ON

	BEGIN
		-- ACTUALIZAMOS LOS REGISTROS DE INTERACCIONES SINCRONAS(CALL) Y RETORNAMOS LOS DETALLES DE LAS QUE SE VAN A TRANSCRIBIR

		-- Actualiza en el primer momento que se consulta a estos registros, con el valor 1 en el campo IsProcess. Indica que se encuentra utilizado por un proceso.
		UPDATE [dbo].[Audio] SET
			[dbo].[Audio].[IsProcess] = 1,	-- Indicar que se esta tomando como procesando para que ningun otro procesamiento en parelelo pueda utilizar el registro.
			[dbo].[Audio].[IsCancel] = null, -- Limpiamos el campo isCancel para retomar los audios que fallaron en procesos pasados
			[dbo].[Audio].[ErrorMessage] = NULL
		
		-- Retornamos todas las columnas a listar.
		OUTPUT INSERTED.[VCC]							'vcc',
				PA.[ProcessId]							'processId',
				'CALL'									'interactionType',
				INSERTED.[ID]							'id',
				INSERTED.[Section]						'section',
				INSERTED.[Part]							'part',
				INSERTED.[StartDate]					'startDate',
				INSERTED.[EndDate]						'endDate',
				INSERTED.[Campaign]						'campaign',
				INSERTED.[DispositionCode]				'dispositionCode',
				INSERTED.[Agent]						'agent',
				INSERTED.[Type]							'origin',
				INSERTED.[RelativePath]					'relativePath',
				INSERTED.[FileName]						'fileName',
				INSERTED.[Format]                       'format',
				INSERTED.[MediaInfoTime]                'mediaInfoTime',
				INSERTED.[NeedI6Update]					'needI6Update',
				0										'isDiariced',
				P.[Language]							'language',
				P.[DictionaryId]						'dictionaryId',
				P.Retranscription						'retranscription',
				P.Diarization							'diarization',
				P.ChannelChange							'channelchange',
				E.[Name]								'name',
				E.[Type]								'environmentType',
				E.[Description]							'description',
				E.[FTPDirectory]						'ftpDirectory',
				E.[ApiHost]								'apiHost',
				E.[ApiPort]								'apiPort',
				E.[ApiUser]								'apiUser',
				E.[ApiPassword]							'apiPassword',
				E.[DbDisabled]							'dbDisabled',
				E.[DbServer]							'dbServer',
				E.[DbPort]								'dbPort',
				E.[DbUser]								'dbUser',
				E.[DbPassword]							'dbPassword',
				E.[PbxDisabled]							'pbxDisabled',
				E.[PbxServer]							'pbxServer',
				E.[PbxPort]								'pbxPort',
				E.[PbxUser]								'pbxUser',
				E.[PbxPassword]							'pbxPassword',
				INSERTED.[DurationTime]					'durationTime',
				INSERTED.[RelativeFileName]				'relativeFileName'
		FROM [dbo].[ProcessAudio] PA (NOLOCK)
		INNER JOIN [dbo].[Audio] A (NOLOCK) 
			ON A.[VCC] = PA.[VCC]
				AND CONCAT(A.[ID], '_', A.[Section], '_', A.[Part]) = CONCAT(PA.[AudioId], '_', PA.[Section], '_', PA.[Part])
		INNER JOIN [dbo].[Process] P (NOLOCK) 
			ON P.[VCC] = A.[VCC]
				AND PA.ProcessId = P.[Name]
		INNER JOIN [dbo].[Environment] E (NOLOCK) 
			ON E.[VCC] = PA.[VCC]
				AND P.[Environment] = E.[Name]
		WHERE A.[VCC] = @VCC
			AND PA.[ProcessId] = @ProcessId
			AND (
				(
					ISNULL(A.[IsProcess], 0) = 0				
					AND 
					ISNULL(A.[IsTranscribed], 0) = 0	-- RETORNAR SOLO LAS INTERACCIONES QUE NO HAYAN SIDO TOMADAS POR OTRO PROCESS
				)
				OR 
				(
					A.[IsProcess] = 1						
					AND 
					A.[IsCancel] = 1
				)
			
				
				
			)					-- RETORNAR SOLO LAS INTERACCIONES QUE HAYAN SIDO TOMADAS Y CANCELADAS POR OTRO PROCESS

		-- ACTUALIZAMOS LOS REGISTROS DE INTERACCIONES ASINCRONAS Y RETORNAMOS LOS DETALLES DE LAS QUE SE VAN A TRANSCRIBIR
		UPDATE [dbo].[AsyncInteraction] 
		SET [dbo].[AsyncInteraction].[IsProcess] = 1,
			[dbo].[AsyncInteraction].[IsCancel] = NULL,
			[dbo].[AsyncInteraction].[ErrorMessage] = NULL
		OUTPUT INSERTED.[VCC]														'vcc',
				P.[Name]															'processId',
				INSERTED.[Channel]													'interactionType',
				INSERTED.[ID]														'id',
				INSERTED.[EndDate]													'endDate',
				INSERTED.[Folder]													'folder',
				INSERTED.[Campaign]													'campaign',
				INSERTED.[DispositionCode]											'dispositionCode',
				ISNULL(INSERTED.[LastTakedAgent], INSERTED.[FirstTakedAgent])		'agent',
				INSERTED.[Initiative]												'origin',
				INSERTED.[TotalMessages]											'totalMessages',
				INSERTED.[RawChar]													'rawChar',
				INSERTED.[ExportedContent]											'exportedContent',
				P.[Language]														'language',
				INSERTED.[FileName]                                                 'fileName',
				'allegro'															'environmentType',
				P.Retranscription													'retranscription'
			
		FROM [dbo].[ProcessAsyncInteraction] PAI (NOLOCK)
		INNER JOIN [dbo].[AsyncInteraction] AI (NOLOCK)
			ON AI.[ID] = PAI.[InteractionId]
				AND AI.[EndDate] = PAI.[EndDate]
		INNER JOIN [dbo].[Process] P (NOLOCK) 
			ON P.[Name] = PAI.[ProcessId] 
		WHERE AI.[VCC] = @VCC
			AND PAI.[ProcessId] = @ProcessId
			AND (
				(
					ISNULL(AI.[IsProcess], 0) = 0
					AND 
					ISNULL(AI.[IsTranscribed], 0) = 0)	-- RETORNAR SOLO LAS INTERACCIONES QUE NO HAYAN SIDO TOMADAS POR OTRO PROCESS
				OR 
				(
					AI.[IsProcess] = 1
					AND 
					AI.[IsCancel] = 1
				)

				
			)					-- RETORNAR SOLO LAS INTERACCIONES QUE HAYAN SIDO TOMADAS Y CANCELADAS POR OTRO PROCESS
	END

	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
